# Molgenis Commander

### Development
Go to the root of the project and create a virtual environment:

```
python3 -m virtualenv env
```

Now enter the environment and install Molgenis Commander in development mode:


```
source env/bin/activate
pip install -e .
```

Now the `mcmd` command will be available in this virtual environment. If you want to
leave the environment, use `deactivate`.
